@@ -9,12 +9,6 @@
 Multipurpose HTML extractor for Plone content
 """
 
-from zope.interface import implements
-from zope.component import adapts
-
-from Products.SmartPrintNG.interfaces import IHTMLExtractor 
-from Products.ATContentTypes.interface.document import IATDocument
-
 from BeautifulSoup import BeautifulSoup
 
 
